==> nextcloud-15.0.6-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ro.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
    "Storage invalid" : "Spațiu de stocare invalid",
    "Unknown error" : "Eroare necunoscută",
    "All files" : "Toate fișierele",
    "Recent" : "Recente",
    "Favorites" : "Favorite",
    "File could not be found" : "Fișierul nu a fost găsit",
    "Move or copy" : "Mută sau copiază",
    "Download" : "Descarcă",
    "Delete" : "Șterge",
    "Home" : "Acasă",
    "Close" : "Închide",
    "Could not create folder \"{dir}\"" : "Nu s-a putut crea directorul \"{dir}\"",
    "Upload cancelled." : "Încărcare anulată.",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nu se poate încărca {filename} deoarece este un director sau are mărimea de 0 octeți",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spațiu liber insuficient, încărcați {size1} însă doar {size2} disponibil rămas",
    "Target folder \"{dir}\" does not exist any more" : "Directorul \"{dir}\" nu mai există",
    "Not enough free space" : "Spațiu insuficient",
    "Uploading …" : "Încărcare...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} din {totalSize} ({bitrate})",
    "Target folder does not exist any more" : "Directorul destinație nu mai există",
    "Actions" : "Acțiuni",
    "Rename" : "Redenumește",
    "Copy" : "Copiază",
    "Open" : "Deschide",
    "Disconnect storage" : "Deconectează stocarea",
    "Unshare" : "Nu mai partaja",
    "Files" : "Fișiere",
    "Details" : "Detalii",
    "Select" : "Alege",
    "Pending" : "În așteptare",
    "Unable to determine date" : "Nu s-a putut determina data",
    "This operation is forbidden" : "Operațiunea este interzisă",
    "This directory is unavailable, please check the logs or contact the administrator" : "Acest director nu este disponibil, te rugăm verifică logurile sau contactează un administrator",
    "Could not move \"{file}\", target exists" : "Nu s-a putut muta fișierul \"{file}\", există deja un altul cu același nume în directorul destinație",
    "Could not move \"{file}\"" : "Nu s-a putut muta fișierul \"{file}\"",
    "Could not copy \"{file}\"" : "Nu s-a putut copia \"{file}\"",
    "Copied {origin} inside {destination}" : "S-a copiat {origin} în {destination}",
    "{newName} already exists" : "{newName} există deja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nu s-a putut redenumi \"{fileName}\", fișierul nu mai există",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Numele \"{targetName}\" este deja folosit în directorul \"{dir}\". Alege un nume diferit.",
    "Could not rename \"{fileName}\"" : "Nu s-a putut redenumi \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nu s-a putut crea fișierul \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nu s-a putut crea fișierul \"{file}\" deoarece există deja unul cu același nume",
    "Could not create folder \"{dir}\" because it already exists" : "Nu s-a putut crea directorul \"{dir}\" deoarece există deja unul cu același nume",
    "Error deleting file \"{fileName}\"." : "Eroare la ștergerea fișierului \"{fileName}\".",
    "Name" : "Nume",
    "Size" : "Mărime",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n director","%n directoare","%n directoare"],
    "_%n file_::_%n files_" : ["%n fișier","%n fișiere","%n fișiere"],
    "{dirs} and {files}" : "{dirs} și {files}",
    "You don’t have permission to upload or create files here" : "Nu aveți permisiunea de a încărca sau crea fișiere aici",
    "_Uploading %n file_::_Uploading %n files_" : ["Se încarcă %n fișier.","Se încarcă %n fișiere.","Se încarcă %n fișiere."],
    "New" : "Nou",
    "{used} of {quota} used" : "{used} din {quota} folosiți",
    "{used} used" : "{used} folosiți",
    "\"{name}\" is an invalid file name." : "\"{name}\" este un nume de fișier nevalid.",
    "File name cannot be empty." : "Numele fișierului nu poate rămâne gol.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Spațiul de stocare pentru {owner} este plin, fișierele nu mai pot fi incărcate sau sincronizate!",
    "Your storage is full, files can not be updated or synced anymore!" : "Spațiul de stocare este plin, fișierele nu mai pot fi actualizate sau sincronizate!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Spațiul de stocare pentru {owner} este aproape plin ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Spațiul de stocare este aproape plin ({usedSpacePercent}%)",
    "Copied!" : "S-a copiat!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiază link direct (funcționeză numai pentru utilizatorii care au acces la acest fișier/director)",
    "Path" : "Cale",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octeți","%n octeți"],
    "Favorited" : "Adăugate la favorite",
    "Favorite" : "Favorit",
    "New folder" : "Un nou dosar",
    "Upload file" : "Încarcă fișier",
    "Remove from favorites" : "Șterge din favorite",
    "Add to favorites" : "Adaugă la favorite",
    "An error occurred while trying to update the tags" : "A apărut o eroare în timpul actualizării etichetelor",
    "Added to favorites" : "Adaugat la favorite",
    "Removed from favorites" : "Șters din favorite",
    "You added {file} to your favorites" : "Ai adaugat {file} în favorite",
    "You removed {file} from your favorites" : "Ai șters {file} din favorite",
    "Created by {user}" : "Creat de {user}",
    "Changed by {user}" : "Modificat de {user}",
    "Deleted by {user}" : "Șters de {user}",
    "Restored by {user}" : "Restaurat de {user}",
    "Renamed by {user}" : "Redenumit de {user}",
    "Moved by {user}" : "Mutat de {user}",
    "\"remote user\"" : "\"utilizator la distanță\"",
    "You created {file}" : "Ai creat {file}",
    "{user} created {file}" : "{user} a creat {file}",
    "{file} was created in a public folder" : "{file} a fost creat într-un director public ",
    "You changed {file}" : "Ai modificat {file}",
    "{user} changed {file}" : "{user} a modificat {file}",
    "You deleted {file}" : "Ai șters {file}",
    "{user} deleted {file}" : "{user} a șters {file}",
    "You restored {file}" : "Ai restaurat {file}",
    "{user} restored {file}" : "{user} a restaurat {file}",
    "You renamed {oldfile} to {newfile}" : "Ai redenumit {oldfile} în {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} a redenumit {oldfile} în {newfile}",
    "You moved {oldfile} to {newfile}" : "Ai mutat{oldfile} în {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} a mutat {oldfile} în {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un fișier a fost adăugat în sau șters din <strong>favorites</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un fișier sau director a fost <strong>modificat</strong> sau <strong>redenumit</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nou fișier sau director a fost <strong>creat</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un fișier sau director a fost <strong>șters</strong>",
    "A file or folder has been <strong>restored</strong>" : "Un fișier sau dosar a fost <strong>restaurat</strong>",
    "Upload (max. %s)" : "Încarcă (max. %s)",
    "%s of %s used" : "%s din %s folosiți",
    "%1$s%% of %2$s used" : "%1$s%% din %2$s utilizat",
    "%s used" : "%s folosiți",
    "Settings" : "Setări",
    "Show hidden files" : "Arată fișierele ascunse",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Folosește această adresă <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">pentru a accesa Fișierele prin WebDAV</a>",
    "No files in here" : "Niciun fișier aici",
    "Upload some content or sync with your devices!" : "Încarcă ceva conținut sau sincronizează cu dispozitivele tale!",
    "No entries found in this folder" : "Niciun element găsit în acest director",
    "Select all" : "Selectează tot",
    "Upload too large" : "Fișierul încărcat este prea mare",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fișierele pe care încerci să le încarci depășesc limita de încărcare maximă admisă pe acest server.",
    "No favorites yet" : "Nu aveți favorite încă",
    "Files and folders you mark as favorite will show up here" : "FIșierele și directoarele pe care le marchezi ca favorite vor apărea aici",
    "Tags" : "Etichete",
    "Deleted files" : "Fișiere șterse",
    "Shared with others" : "Partajat cu alții",
    "Shared with you" : "Partajat cu tine",
    "Shared by link" : "Partajat prin link",
    "Text file" : "Fișier text",
    "New text file.txt" : "New text file.txt",
    "Target folder" : "Directorul destinație",
    "File handling" : "Manipulare fișiere",
    "Maximum upload size" : "Dimensiune maximă admisă la încărcare",
    "max. possible: " : "max. posibil:",
    "Save" : "Salvează",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Cu PHP-FPM poate dura 5 minute pentru a aplica schimbările..",
    "Missing permissions to edit from here." : "Nu ai permisiuni pentru a edita aici.",
    "Cancel upload" : "Anulează încărcarea",
    "%1$s of %2$s used" : "%1$s din %2$s utilizat"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");

==> nextcloud-17.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/ro.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
    "Storage invalid" : "Spațiu de stocare invalid",
    "Unknown error" : "Eroare necunoscută",
    "All files" : "Toate fișierele",
    "Recent" : "Recente",
    "Favorites" : "Favorite",
    "File could not be found" : "Fișierul nu a fost găsit",
    "Move or copy" : "Mută sau copiază",
    "Download" : "Descarcă",
    "Delete" : "Șterge",
    "Home" : "Acasă",
    "Close" : "Închide",
    "Could not create folder \"{dir}\"" : "Nu s-a putut crea directorul \"{dir}\"",
    "This will stop your current uploads." : "Asta va opri descărcările curente.",
    "Upload cancelled." : "Încărcare anulată.",
    "Processing files …" : "Procesare fișiere ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nu se poate încărca {filename} deoarece este un director sau are mărimea de 0 octeți",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spațiu liber insuficient, încărcați {size1} însă doar {size2} disponibil rămas",
    "Target folder \"{dir}\" does not exist any more" : "Directorul \"{dir}\" nu mai există",
    "Not enough free space" : "Spațiu insuficient",
    "An unknown error has occurred" : "A apărut o eroare necunoscută!",
    "Uploading …" : "Încărcare...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} din {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Încărcarea acestui obiect nu este suportată",
    "Target folder does not exist any more" : "Directorul destinație nu mai există",
    "Error when assembling chunks, status code {status}" : "Eroare la asambralea bucăților, status cod {status}",
    "Actions" : "Acțiuni",
    "Rename" : "Redenumește",
    "Copy" : "Copiază",
    "Choose target folder" : "Alege directorul destinație",
    "Open" : "Deschide",
    "Delete file" : "Șterge fișier",
    "Delete folder" : "Șterge director",
    "Disconnect storage" : "Deconectează stocarea",
    "Unshare" : "Nu mai partaja",
    "Could not load info for file \"{file}\"" : "Nu s-a putut încărca informația pentru fișierul \"{file}\"",
    "Files" : "Fișiere",
    "Details" : "Detalii",
    "Select" : "Alege",
    "Pending" : "În așteptare",
    "Unable to determine date" : "Nu s-a putut determina data",
    "This operation is forbidden" : "Operațiunea este interzisă",
    "This directory is unavailable, please check the logs or contact the administrator" : "Acest director nu este disponibil, te rugăm verifică logurile sau contactează un administrator",
    "Could not move \"{file}\", target exists" : "Nu s-a putut muta fișierul \"{file}\", există deja un altul cu același nume în directorul destinație",
    "Could not move \"{file}\"" : "Nu s-a putut muta fișierul \"{file}\"",
    "copy" : "copiază",
    "Could not copy \"{file}\", target exists" : "Nu s-a putut copia \"{file}\", există deja un altul cu același nume în directorul destinație",
    "Could not copy \"{file}\"" : "Nu s-a putut copia \"{file}\"",
    "Copied {origin} inside {destination}" : "S-a copiat {origin} în {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "S-a copiat {origin} și {nbfiles} alte fișiere în {destination}",
    "{newName} already exists" : "{newName} există deja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nu s-a putut redenumi \"{fileName}\", fișierul nu mai există",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Numele \"{targetName}\" este deja folosit în directorul \"{dir}\". Alege un nume diferit.",
    "Could not rename \"{fileName}\"" : "Nu s-a putut redenumi \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nu s-a putut crea fișierul \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nu s-a putut crea fișierul \"{file}\" deoarece există deja unul cu același nume",
    "Could not create folder \"{dir}\" because it already exists" : "Nu s-a putut crea directorul \"{dir}\" deoarece există deja unul cu același nume",
    "Error deleting file \"{fileName}\"." : "Eroare la ștergerea fișierului \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nu au fost găsite rezultate în alte directoare pentru {tag}{filter}{endtag}",
    "Name" : "Nume",
    "Size" : "Mărime",
    "Modified" : "Modificat",
    "_%n folder_::_%n folders_" : ["%n director","%n directoare","%n directoare"],
    "_%n file_::_%n files_" : ["%n fișier","%n fișiere","%n fișiere"],
    "{dirs} and {files}" : "{dirs} și {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluzând %n ascuns","incluzând %nascunse","incluzând %nascuns"],
    "You don’t have permission to upload or create files here" : "Nu aveți permisiunea de a încărca sau crea fișiere aici",
    "_Uploading %n file_::_Uploading %n files_" : ["Se încarcă %n fișier.","Se încarcă %n fișiere.","Se încarcă %n fișiere."],
    "New" : "Nou",
    "Select file range" : "Selectează un interval",
    "{used} of {quota} used" : "{used} din {quota} folosiți",
    "{used} used" : "{used} folosiți",
    "\"{name}\" is an invalid file name." : "\"{name}\" este un nume de fișier nevalid.",
    "File name cannot be empty." : "Numele fișierului nu poate rămâne gol.",
    "\"/\" is not allowed inside a file name." : "\"/\" nu este permis în denumirea fișierului.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "Spațiul de stocare pentru {owner} este plin, fișierele nu mai pot fi incărcate sau sincronizate!",
    "Your storage is full, files can not be updated or synced anymore!" : "Spațiul de stocare este plin, fișierele nu mai pot fi actualizate sau sincronizate!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "Spațiul de stocare pentru {owner} este aproape plin ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "Spațiul de stocare este aproape plin ({usedSpacePercent}%)",
    "View in folder" : "Vizualizează în director",
    "Copied!" : "S-a copiat!",
    "Copy direct link (only works for users who have access to this file/folder)" : "Copiază link direct (funcționeză numai pentru utilizatorii care au acces la acest fișier/director)",
    "Path" : "Cale",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octeți","%n octeți"],
    "Favorited" : "Adăugate la favorite",
    "Favorite" : "Favorit",
    "You can only favorite a single file or folder at a time" : "Poți adauga la favorite un singur fișier sau director odată",
    "New folder" : "Un nou dosar",
    "Upload file" : "Încarcă fișier",
    "Not favorited" : "Scoate de la favorite",
    "Remove from favorites" : "Șterge din favorite",
    "Add to favorites" : "Adaugă la favorite",
    "An error occurred while trying to update the tags" : "A apărut o eroare în timpul actualizării etichetelor",
    "Added to favorites" : "Adaugat la favorite",
    "Removed from favorites" : "Șters din favorite",
    "You added {file} to your favorites" : "Ai adaugat {file} în favorite",
    "You removed {file} from your favorites" : "Ai șters {file} din favorite",
    "File changes" : "Modificări fișiere",
    "Created by {user}" : "Creat de {user}",
    "Changed by {user}" : "Modificat de {user}",
    "Deleted by {user}" : "Șters de {user}",
    "Restored by {user}" : "Restaurat de {user}",
    "Renamed by {user}" : "Redenumit de {user}",
    "Moved by {user}" : "Mutat de {user}",
    "\"remote user\"" : "\"utilizator la distanță\"",
    "You created {file}" : "Ai creat {file}",
    "You created an encrypted file in {file}" : "Ai creat un fișier criptat în {file}",
    "{user} created {file}" : "{user} a creat {file}",
    "{user} created an encrypted file in {file}" : "{user} a creat un fișier criptat în {file}",
    "{file} was created in a public folder" : "{file} a fost creat într-un director public ",
    "You changed {file}" : "Ai modificat {file}",
    "You changed an encrypted file in {file}" : "Ai modificat un fișier criptat în {file}",
    "{user} changed {file}" : "{user} a modificat {file}",
    "{user} changed an encrypted file in {file}" : "{user} a modificat un fișier criptat în {file}",
    "You deleted {file}" : "Ai șters {file}",
    "You deleted an encrypted file in {file}" : "Ai șters un fișier criptat în {file}",
    "{user} deleted {file}" : "{user} a șters {file}",
    "{user} deleted an encrypted file in {file}" : "{user} a șters un fișier criptat în {file}",
    "You restored {file}" : "Ai restaurat {file}",
    "{user} restored {file}" : "{user} a restaurat {file}",
    "You renamed {oldfile} to {newfile}" : "Ai redenumit {oldfile} în {newfile}",
    "{user} renamed {oldfile} to {newfile}" : "{user} a redenumit {oldfile} în {newfile}",
    "You moved {oldfile} to {newfile}" : "Ai mutat {oldfile} în {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} a mutat {oldfile} în {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un fișier a fost adăugat în sau șters din <strong>favorites</strong>",
    "A file or folder has been <strong>changed</strong> or <strong>renamed</strong>" : "Un fișier sau director a fost <strong>modificat</strong> sau <strong>redenumit</strong>",
    "A new file or folder has been <strong>created</strong>" : "Un nou fișier sau director a fost <strong>creat</strong>",
    "A file or folder has been <strong>deleted</strong>" : "Un fișier sau director a fost <strong>șters</strong>",
    "Limit notifications about creation and changes to your <strong>favorite files</strong> <em>(Stream only)</em>" : "Limitează notificările despre crearea sau schimbările<strong> fișierelor tale favorite</strong> <em>(numai pentru flux)</em>  ",
    "A file or folder has been <strong>restored</strong>" : "Un fișier sau dosar a fost <strong>restaurat</strong>",
    "Unlimited" : "Nelimitată",
    "Upload (max. %s)" : "Încarcă (max. %s)",
    "File Management" : "Management fișiere",
    "%s used" : "%s folosiți",
    "%s%% of %s used" : "%s%%din %sfolosiți",
    "%1$s of %2$s used" : "%1$s din %2$s utilizat",
    "Settings" : "Setări",
    "Show hidden files" : "Arată fișierele ascunse",
    "WebDAV" : "WebDAV",
    "Use this address to <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">access your Files via WebDAV</a>" : "Folosește această adresă <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">pentru a accesa Fișierele prin WebDAV</a>",
    "Toggle grid view" : "Comută vizualizarea grilă",
    "No files in here" : "Niciun fișier aici",
    "Upload some content or sync with your devices!" : "Încarcă ceva conținut sau sincronizează cu dispozitivele tale!",
    "No entries found in this folder" : "Niciun element găsit în acest director",
    "Select all" : "Selectează tot",
    "Upload too large" : "Fișierul încărcat este prea mare",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fișierele pe care încerci să le încarci depășesc limita de încărcare maximă admisă pe acest server.",
    "No favorites yet" : "Nu aveți favorite încă",
    "Files and folders you mark as favorite will show up here" : "FIșierele și directoarele pe care le marchezi ca favorite vor apărea aici",
    "Tags" : "Etichete",
    "Deleted files" : "Fișiere șterse",
    "Shares" : "Partajări",
    "Shared with others" : "Partajat cu alții",
    "Shared with you" : "Partajat cu tine",
    "Shared by link" : "Partajat prin link",
    "Deleted shares" : "Partajări șterse",
    "Text file" : "Fișier text",
    "New text file.txt" : "Fișier nou.txt",
    "File handling" : "Manipulare fișiere",
    "Maximum upload size" : "Dimensiune maximă admisă la încărcare",
    "max. possible: " : "max. posibil:",
    "Save" : "Salvează",
    "With PHP-FPM it might take 5 minutes for changes to be applied." : "Cu PHP-FPM poate dura 5 minute pentru a aplica schimbările..",
    "Missing permissions to edit from here." : "Nu ai permisiuni pentru a edita aici.",
    "Cancel upload" : "Anulează încărcarea",
    "%s of %s used" : "%s din %s folosiți",
    "%1$s%% of %2$s used" : "%1$s%% din %2$s utilizat"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
